==> haskell-hxt-charproperties-9.2.0.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-DFKuHAMsc8NJwk1yc4YSyO
key: hxt-charproperties-9.2.0.1-DFKuHAMsc8NJwk1yc4YSyO
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
author: Uwe Schmidt
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
abi: 44ab63d147932ce734e2efa3c8ca00f5
exposed: True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
import-dirs: /usr/lib/ghc-8.4.3/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hxt-charproperties-9.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-DFKuHAMsc8NJwk1yc4YSyO
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.2.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-FrM4lHkFZYa1rulBEgP7qk
key: hxt-charproperties-9.2.0.1-FrM4lHkFZYa1rulBEgP7qk
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
author: Uwe Schmidt
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
abi: 55d09c223180bb5ffc7057db4afbf08e
exposed: True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
import-dirs: /usr/lib/ghc-8.6.1/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/hxt-charproperties-9.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-FrM4lHkFZYa1rulBEgP7qk
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
